# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-26 15:35
from __future__ import unicode_literals

import collections
from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djiffy', '0002_view_permissions'),
    ]

    operations = [
        migrations.AddField(
            model_name='canvas',
            name='extra_data',
            field=jsonfield.fields.JSONField(default=collections.OrderedDict),
        ),
        migrations.AlterField(
            model_name='manifest',
            name='extra_data',
            field=jsonfield.fields.JSONField(default=collections.OrderedDict),
        ),
    ]
